psiTurk Dashboard

The psiTurk dashboard is loading...

### Warning

You are about to shutdown the psiTurk server. If there are any participants currently running in your experiment, they will be forced to quit. You are still responsible for their payment.

### Welcome!

To begin psiTurk, please provide your Amazon Mechanical Turk credentials.

An AWS key is required for posting new HITs to mechanical turk as well as monitoring existing HITs. You receive your key when you open an Amazon Web Services account. If you already have an AWS account, your key can be retrieved from: https://console.aws.amazon.com/iam/home?#security_credential
Your Access Key Id
Secret Access Key

### Expire experiment

Warning! Terminating experiment early.

### Extend experiment

Please use the following fields to extend the HIT.

Extend time (mins.) |  | Extend number of workers |

### psiTurk dashboard off

To restart, please close this window and launch psiturk from the terminal.